==> compass-client-0.1.111-sources.jar: com/xforceplus/compass/controller/MiroOrderDetailFeignApi.java <==
package com.xforceplus.compass.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-08-11
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.compass.entity.MiroOrderDetail;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "compass")
public interface MiroOrderDetailFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/miroOrderDetail/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param miroOrderDetail ${table.comment}
   * @return R
   */
  @PostMapping("/miroOrderDetail/add")
  public R save(@RequestBody MiroOrderDetail miroOrderDetail);

  /**
   * 修改${table.comment}
   * @param miroOrderDetail ${table.comment}
   * @return R
   */
  @PostMapping("/miroOrderDetail/update")
  public R updateById(@RequestBody MiroOrderDetail miroOrderDetail);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/miroOrderDetail/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> compass-client-0.1.222-sources.jar: com/xforceplus/compass/controller/MiroOrderDetailFeignApi.java <==
package com.xforceplus.compass.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2025-09-23
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.compass.entity.MiroOrderDetail;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "compass")
public interface MiroOrderDetailFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/miroOrderDetail/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param miroOrderDetail ${table.comment}
   * @return R
   */
  @PostMapping("/miroOrderDetail/add")
  public R save(@RequestBody MiroOrderDetail miroOrderDetail);

  /**
   * 修改${table.comment}
   * @param miroOrderDetail ${table.comment}
   * @return R
   */
  @PostMapping("/miroOrderDetail/update")
  public R updateById(@RequestBody MiroOrderDetail miroOrderDetail);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/miroOrderDetail/del/{id}" )
  public R removeById(@PathVariable Long id);

}
